@@ -3,33 +3,26 @@ import pygame_gui as pg_g
 from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
 
 CARDS = ['Brick', 'Ore', 'Sheep', 'Wheat', 'Wood']
+TITLE_SPACING = 28
 
 
-class CardPickerGui:
-    def __init__(self, top_left, manager, callback, container=None):
+class CardPickerGui(pg_g.elements.UIWindow):
+    def __init__(self, top_left, manager, callback):
+        super().__init__(pygame.Rect(top_left, ((CARD_SIZE[0] + SPACING) * 5 + 10 * SPACING, CARD_SIZE[1] + 10 * SPACING + TITLE_SPACING)), manager)
         self.manager = manager
         self.callback = callback
-        self.panel = pg_g.elements.UIPanel(
-            relative_rect=pygame.Rect(top_left,
-                                      ((CARD_SIZE[0] + SPACING) * 5 + 10 * SPACING, CARD_SIZE[1] + 10 * SPACING)),
-            starting_layer_height=1,
-            manager=self.manager,
-            container=container,
-        )
         self.cards = []
+        self.close_window_button.disable()
 
         for i, card in enumerate(CARDS):
             self.cards.append(pg_g.elements.UIButton(
-                relative_rect=pygame.Rect((i * (CARD_SIZE[0] + SPACING) + 4 * SPACING, 4 * SPACING), CARD_SIZE),
+                relative_rect=pygame.Rect((i * (CARD_SIZE[0] + SPACING), 0), CARD_SIZE),
                 text="",
                 manager=self.manager,
-                container=self.panel,
+                container=self,
                 object_id="#" + card
             ))
 
-    def kill(self):
-        self.panel.kill()
-
     def handle_ui_button_pressed(self, event):
         try:
             index = self.cards.index(event.ui_element)
