@@ -77,7 +77,7 @@ class card:
 
 
 class card_animation:
-    def __init__(self, card_obj, callback, init, dest, steps):
+    def __init__(self, card_obj, callback, init, dest, steps, fps=30):
         # print('animation created')
         self.card = card_obj
 
@@ -105,8 +105,8 @@ class card_animation:
 
         self.location = init
 
-        self.step_size_x = (self.dest[0] - self.init[0]) / steps
-        self.step_size_y = (self.dest[1] - self.init[1]) / steps
+        self.step_size_x = (self.dest[0] - self.init[0]) / steps / (fps / 30)
+        self.step_size_y = (self.dest[1] - self.init[1]) / steps / (fps / 30)
 
         self.steps_done = 0
 
@@ -177,6 +177,9 @@ class Client:
         self.trade_list = []
         self.turn_player = ''
         self.post_url = post_url
+        self.counter = 0
+        self.target_fps = 10
+        self.counter_max = 1/self.target_fps
         # todo initialize the rest of these
         self.card_keys = []
         self.turn_ended = False
@@ -358,19 +361,22 @@ class Client:
         cards_removed = []
         index = 0
         # print('MINE', list_cards)
+
+        time = self.clock.get_fps()
+
         for card_t in card_type:
             if list_cards[index] > 0:
                 card_lost = card(location_start, card_t)
                 for anything in range(0, list_cards[index]):
                     self.animations.append(
-                        card_animation(card_lost, None, location_start, location_end, location_steps))
+                        card_animation(card_lost, None, location_start, location_end, location_steps, time))
                     cards_removed.append(card_lost.resource)
 
             if list_cards[index] < 0:
                 card_gained = card(location_start, card_t)
                 for anything in range(list_cards[index], 0):
                     self.animations.append(
-                        card_animation(card_gained, self.add_card, location_end, location_start, location_steps))
+                        card_animation(card_gained, self.add_card, location_end, location_start, location_steps, time))
             index += 1
         self.remove_card(cards_removed)
         # self.card_keys = card_keys
@@ -1405,8 +1411,8 @@ class Client:
         if self.text_dialog is not None:
             self.text_dialog.add_line(text)
 
-    def update_frame(self):
-        time_delta = self.clock.tick(30) / 1000.0
+    def update_frame(self, time_delta):
+        #time_delta = self.clock.tick(30) / 1000.0
         if self.board_updated:
             self.info_panel.set_bank_info(self.bank)
             self.info_panel.set_player_info(self.player, self.enemy_list, self.turn_player)
@@ -1438,11 +1444,20 @@ class Client:
         except AttributeError:
             pass
         self.draw_board()
-
+        
         if self.is_rolling:
-            self.display_dice([random.randint(1, 6), random.randint(1, 6)])
-        self.manager.draw_ui(self.game_window)
+            if self.counter >= self.counter_max:
+                self.display_dice([random.randint(1, 6), random.randint(1, 6)])
+                self.counter %= self.counter_max
+            else:
+                self.counter += time_delta
+        
 
+            
+        try:    
+            self.manager.draw_ui(self.game_window)
+        except AttributeError:
+             pass
         if len(self.animations) > 0:
             for animation in self.animations:
                 if animation.update():
@@ -1560,4 +1575,8 @@ class Client:
             for butt in self.robber_butts:
                 butt.draw(graphics)
 
+        #text = str(self.clock.get_fps() // 1)
+        #text_surface = pygame.font.Font.render(self.font, text[:-2], True, (255, 255, 255), None)
+        #graphics.blit(text_surface, (0, 0))
+
         self.game_window.blit(graphics, (0, 0))
