@@ -5,57 +5,59 @@ from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
 CARDS = ['Brick', 'Ore', 'Sheep', 'Wheat', 'Wood']
 
 
-class TraderGui:
-    def __init__(self, top_left, resource_hand, trade_ratios, manager, callback, container=None):
+class TraderGui(pg_g.elements.UIWindow):
+    def __init__(self, top_left, resource_hand, trade_ratios, manager, callback, callback_close=None):
+        super().__init__(pygame.Rect(top_left, ((CARD_SIZE[0] + SPACING) * 20, (CARD_SIZE[1] + SPACING) * 3 + 10 * SPACING + 28)), manager)
         self.resource_hand = resource_hand
         self.trade_ratios = trade_ratios
         self.manager = manager
         self.callback = callback
+        self.callback_close = callback_close
         self.is_valid = False
         self.error_text = ""
 
-        self.panel = pg_g.elements.UIPanel(
-            relative_rect=pygame.Rect(top_left, ((CARD_SIZE[0] + SPACING) * 20, (CARD_SIZE[1] + SPACING) * 3)),
-            starting_layer_height=5,
-            manager=self.manager,
-            container=container,
-        )
+        if self.callback_close is None:
+            self.close_window_button.disable()
+
         self.give_panel = pg_g.elements.UIPanel(
-            relative_rect=pygame.Rect(0, 0, self.panel.relative_rect.width / 2, CARD_SIZE[1] + 2 * SPACING),
+            relative_rect=pygame.Rect(0, 0, self.relative_rect.width / 2, CARD_SIZE[1] + 2 * SPACING),
             starting_layer_height=1,
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
         self.give_card_keys = []
         self.give_card_elements = []
         self.take_panel = pg_g.elements.UIPanel(
-            relative_rect=pygame.Rect(self.give_panel.relative_rect.right, 0, self.panel.relative_rect.width / 2, CARD_SIZE[1] + 2 * SPACING),
+            relative_rect=pygame.Rect(self.give_panel.relative_rect.right, 0, self.relative_rect.width / 2,
+                                      CARD_SIZE[1] + 2 * SPACING),
             starting_layer_height=1,
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
         self.take_card_keys = []
         self.take_card_elements = []
 
-        card_offset = (self.panel.relative_rect.width / 2 - 5 * CARD_SIZE[0]) / 6
+        card_offset = (self.relative_rect.width / 2 - 5 * CARD_SIZE[0]) / 6
 
         self.give_buttons = [
             pg_g.elements.UIButton(
                 relative_rect=pygame.Rect(
-                    (self.give_panel.relative_rect.left + card_offset + i * (CARD_SIZE[0] + card_offset), self.give_panel.relative_rect.bottom + SPACING), CARD_SIZE),
+                    (self.give_panel.relative_rect.left + card_offset + i * (CARD_SIZE[0] + card_offset),
+                     self.give_panel.relative_rect.bottom + SPACING), CARD_SIZE),
                 text="",
                 manager=self.manager,
-                container=self.panel,
+                container=self,
                 object_id="#" + card,
             ) for i, card in enumerate(CARDS)
         ]
         self.take_buttons = [
             pg_g.elements.UIButton(
                 relative_rect=pygame.Rect(
-                    (self.take_panel.relative_rect.left + card_offset + i * (CARD_SIZE[0] + card_offset), self.take_panel.relative_rect.bottom + SPACING), CARD_SIZE),
+                    (self.take_panel.relative_rect.left + card_offset + i * (CARD_SIZE[0] + card_offset),
+                     self.take_panel.relative_rect.bottom + SPACING), CARD_SIZE),
                 text="",
                 manager=self.manager,
-                container=self.panel,
+                container=self,
                 object_id="#" + card
             ) for i, card in enumerate(CARDS)
         ]
@@ -65,9 +67,9 @@ class TraderGui:
                 self.give_buttons[0].relative_rect.left, self.give_buttons[0].relative_rect.bottom + SPACING,
                 self.give_buttons[0].relative_rect.width, 35
             ),
-            html_text=str(self.trade_ratios.brick) + ":1",  # todo replace with value from self.trade_ratios
+            html_text=str(self.trade_ratios.brick) + ":1",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
 
         pg_g.elements.UITextBox(
@@ -75,9 +77,9 @@ class TraderGui:
                 self.give_buttons[1].relative_rect.left, self.give_buttons[1].relative_rect.bottom + SPACING,
                 self.give_buttons[1].relative_rect.width, 35
             ),
-            html_text=str(self.trade_ratios.ore) + ":1",  # todo replace with value from self.trade_ratios
+            html_text=str(self.trade_ratios.ore) + ":1",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
 
         pg_g.elements.UITextBox(
@@ -85,9 +87,9 @@ class TraderGui:
                 self.give_buttons[2].relative_rect.left, self.give_buttons[2].relative_rect.bottom + SPACING,
                 self.give_buttons[1].relative_rect.width, 35
             ),
-            html_text=str(self.trade_ratios.wool) + ":1",  # todo replace with value from self.trade_ratios
+            html_text=str(self.trade_ratios.wool) + ":1",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
 
         pg_g.elements.UITextBox(
@@ -95,9 +97,9 @@ class TraderGui:
                 self.give_buttons[3].relative_rect.left, self.give_buttons[3].relative_rect.bottom + SPACING,
                 self.give_buttons[3].relative_rect.width, 35
             ),
-            html_text=str(self.trade_ratios.grain) + ":1",  # todo replace with value from self.trade_ratios
+            html_text=str(self.trade_ratios.grain) + ":1",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
 
         pg_g.elements.UITextBox(
@@ -105,47 +107,45 @@ class TraderGui:
                 self.give_buttons[4].relative_rect.left, self.give_buttons[4].relative_rect.bottom + SPACING,
                 self.give_buttons[4].relative_rect.width, 35
             ),
-            html_text=str(self.trade_ratios.lumber) + ":1",  # todo replace with value from self.trade_ratios
+            html_text=str(self.trade_ratios.lumber) + ":1",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
 
         button_width = 300
         button_spacing = (self.take_panel.relative_rect.width - 2 * button_width) / 3
         self.trade_with_bank_button = pg_g.elements.UIButton(
             relative_rect=pygame.Rect(
-                self.take_panel.relative_rect.left + button_spacing, self.take_buttons[0].relative_rect.bottom + SPACING,
+                self.take_panel.relative_rect.left + button_spacing,
+                self.take_buttons[0].relative_rect.bottom + SPACING,
                 button_width, 45
             ),
             text="Trade with bank",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
         self.trade_with_player_button = pg_g.elements.UIButton(
             relative_rect=pygame.Rect(
-                self.take_panel.relative_rect.left + 2 * button_spacing + button_width, self.take_buttons[0].relative_rect.bottom + SPACING,
+                self.take_panel.relative_rect.left + 2 * button_spacing + button_width,
+                self.take_buttons[0].relative_rect.bottom + SPACING,
                 button_width, 45
             ),
             text="Trade with players",
             manager=self.manager,
-            container=self.panel,
+            container=self,
         )
-        # todo remove line
-        # self.trade_with_player_button.enable()
+
         self.info_text = pg_g.elements.UITextBox(
             relative_rect=pygame.Rect(
-                0, self.trade_with_bank_button.relative_rect.bottom, self.panel.relative_rect.width - 2 * SPACING, 35
+                0, self.trade_with_bank_button.relative_rect.bottom, self.relative_rect.width - 2 * SPACING, 35
             ),
             html_text=self.error_text,
             manager=self.manager,
-            container=self.panel
+            container=self
         )
 
         self.validate_trade()
 
-    def kill(self):
-        self.panel.kill()
-
     def update_give_cards(self):
         for elem in self.give_card_elements:
             elem.kill()
@@ -230,7 +230,7 @@ class TraderGui:
         else:
             self.give_buttons[4].enable()
 
-        # prevent too many cards in request hand, todo check this
+        # prevent too many cards in request hand
         if brick + ore + wool + grain + lumber > 7:
             for button in self.take_buttons:
                 button.disable()
@@ -285,18 +285,18 @@ class TraderGui:
         self.info_text.kill()
         self.info_text = pg_g.elements.UITextBox(
             relative_rect=pygame.Rect(
-                0, self.trade_with_bank_button.relative_rect.bottom, self.panel.relative_rect.width - 2 * SPACING, 35
+                0, self.trade_with_bank_button.relative_rect.bottom, self.relative_rect.width - 2 * SPACING, 35
             ),
             html_text=self.error_text,
             manager=self.manager,
-            container=self.panel
+            container=self
         )
         if self.is_valid:
             self.trade_with_bank_button.enable()
         else:
             self.trade_with_bank_button.disable()
 
-    def handle_ui_button_pressed(self, event):  # Todo
+    def handle_ui_button_pressed(self, event):
         if event.ui_element in self.give_buttons:
             try:
                 index = self.give_buttons.index(event.ui_element)
@@ -329,3 +329,8 @@ class TraderGui:
             self.callback('tradebank', self.give_card_keys, self.take_card_keys)
         elif event.ui_element == self.trade_with_player_button:
             self.callback('tradeplayer', self.give_card_keys, self.take_card_keys)
+
+    def process_event(self, event):
+        if self.callback_close is not None and event.type == pygame.USEREVENT and event.user_type == 'ui_button_pressed' and event.ui_element == self.close_window_button:
+            self.callback_close()
+        super().process_event(event)
