@@ -4,7 +4,7 @@ import math
 # Class defining corners of hexagons
 class CornerNode:
     @staticmethod
-    def translate_settlement(location, origin, radius, sideLength=3):
+    def translate_settlement_old(location, origin, radius, sideLength=3):
         toReturnX = 0
         toReturnY = 0
         edgeDist = (radius / 2) * math.sqrt(3)
@@ -26,6 +26,30 @@ class CornerNode:
 
         return int(toReturnX + totalXOffset), int(toReturnY + totalYOffset)
 
+    @staticmethod
+    def translate_settlement(location, origin, radius, sideLength=3):
+        x_diff = radius
+        y_diff = radius
+
+        x_off = 0
+        y_off = 0
+
+        x_step = location[0] - 5
+        x_factor = 3 ** 0.5 / 2
+        x_off = x_factor * x_step * radius
+
+        y_zero = origin[1] - 4 * radius
+        y_step = 1 / 2 * radius
+
+        if x_step in (-5, -3, -1, 1, 3, 5):
+            y_bonus = location[1] // 2
+            y_off = y_step + location[1] * radius + y_bonus * radius
+        else:
+            y_bonus = (location[1] + 1) // 2
+            y_off = location[1] * radius + y_bonus * radius
+
+        return int(origin[0] + x_off + x_diff), int(y_off + y_diff + y_zero)
+
     def __init__(self, r=False, c1=None, c2=None):
         self.real = r
         self.hexs = list()
@@ -72,7 +96,7 @@ class CornerNode:
 
 class EdgeNode:
     @staticmethod
-    def translate_road(location, origin, radius, sideLength=3):
+    def translate_road_old(location, origin, radius, sideLength=3):
         toReturnX = 0
         toReturnY = 0
         edgeDist = (radius / 2) * math.sqrt(3)
@@ -90,6 +114,24 @@ class EdgeNode:
 
         return int(toReturnX + totalXOffset), int(toReturnY + totalYOffset)
 
+    @staticmethod
+    def translate_road(location, origin, radius, sideLength=3):
+
+        x_offset = 0
+        y_offset = 0
+        y_diff = radius
+        x_diff = radius
+
+        x_step = location[0] - 10
+        x_factor = 3 ** 0.5 / 4
+        x_offset = x_factor * radius * x_step
+
+        y_step = location[1] - 5
+        y_factor = 3 / 4
+        y_offset = y_factor * radius * y_step
+
+        return int(x_offset + origin[0] + x_diff), int(y_offset + origin[1] + y_diff)
+
     def __init__(self, r=False, c1=None, c2=None):
         self.real = r
         self.hexs = list()
@@ -119,8 +161,6 @@ class EdgeNode:
         for corner in self.corners:
             if corner != baseCorner and corner is not None:
                 return corner
-        else:
-            print("Error, not a corner not attached to this edge")
 
     def claim(self, color):
         self.color = color
@@ -398,5 +438,3 @@ class StructureBoard:
         return toReturn
 
     # def initilizaeHexes(self, hexArray):
-
-
